/*
 * Copyright (c) 2003-2011, Simon Brown
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 *   - Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the following disclaimer.
 *
 *   - Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in
 *     the documentation and/or other materials provided with the
 *     distribution.
 *
 *   - Neither the name of Pebble nor the names of its contributors may
 *     be used to endorse or promote products derived from this software
 *     without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */
package net.sourceforge.pebble.web.action;

import net.sourceforge.pebble.util.ExceptionUtils;
import net.sourceforge.pebble.web.view.View;
import net.sourceforge.pebble.web.view.impl.ErrorView;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import javax.servlet.ServletException;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.util.Enumeration;

/**
 * Redirects the user to a error page.
 *
 * @author    Simon Brown
 */
public class ErrorAction extends Action {

  /** the log used by this class */
  private static final Log log = LogFactory.getLog(ErrorAction.class);

  /**
   * Peforms the processing associated with this action.
   *
   * @param request  the HttpServletRequest instance
   * @param response the HttpServletResponse instance
   * @return the name of the next view
   */
  public View process(HttpServletRequest request, HttpServletResponse response) throws ServletException {
    Exception e = (Exception)request.getAttribute("exception");
    if (e == null) {
      Object exceptionAttribute = request.getAttribute("javax.servlet.error.exception");
      if (exceptionAttribute instanceof Exception) {
        e = (Exception) exceptionAttribute;
      }
    }
    if (e != null) {
      log.error("Request URL = " + request.getRequestURL());
      log.error("Request URI = " + request.getRequestURI());
      log.error("Query string = " + request.getQueryString());
      Enumeration en = request.getHeaderNames();
      while (en.hasMoreElements()) {
        String headerName = (String)en.nextElement();
        log.error(headerName + " = " + request.getHeader("headerName"));
      }
      log.error("Parameters :");
      java.util.Enumeration names = request.getParameterNames();
      while (names.hasMoreElements()) {
        String name = (String)names.nextElement();
        log.error(" " + name + " = " + request.getParameter(name));
      }

      log.error("Exception encountered", e);

      getModel().put("stackTrace", ExceptionUtils.getStackTraceAsString(e));
    }

    return new ErrorView();
  }

}